from setuptools import setup, find_packages

setup(
    name="andrex_rubik",
    version="0.1.0",
    author="Andrex",
    author_email="xxxpvox@gmail.com",
    description="Libreria Python per il riconoscimento e risoluzione del cubo di Rubik",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/Andrex07Dev/AndrexGPt/releases/",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
    install_requires=[
        "requests"
    ],
)